Buffer

Struct Buffer 

pub struct Buffer { /* private fields */ }
Buffer with maximum capacity that rotates itself.

Implementations

Source

impl Buffer

pub fn from_array(capacity: usize, data: &[Num]) -> Result<Self, TAError>

Creates a new buffer from the data provided. If the data’s length is less than the capacity provided, the oldest values will be padded with the default value of T and and is_ready() will be false. If the data’s length is >= capacity, it takes the last values of data and is_ready() will be true.

Arguments
  • capacity - Total size of the buffer, must be > 0.
  • data - Array of data to fill with. Newest -> Oldest.
pub fn capacity(&self) -> usize

Maximum capacity the buffer can hold.

pub fn is_ready(&self) -> bool

Checks if the buffer is ready indicating it has data to meet its capacity.

pub fn oldest(&self) -> Num

Gets the oldest value in the buffer, this is the next value that will be removed.

pub fn newest(&self) -> Num

Gets the newest value in the buffer, this value will current live the longest in the buffer.

pub fn queue(&self) -> &[Num]

Returns the data held by the buffer from Oldest -> Newest. Index 0 being the oldest and next value to be removed. Index (len-1) being the newest data.

pub fn shift(&mut self, value: Num) -> Num

Adds a new (newest) value to the buffer. Oldest value is removed and returned.

Arguments
  • value - New (newest) value to add to the buffer.
pub fn sum(&self) -> Num

Obtain the sum of the buffer.

pub fn mean(&self) -> Num

Calculates the mean of the buffer.

pub fn variance(&self, is_sample: bool) -> Num

Calculates the variance of the buffer.

Arguments
  • is_sample - If the data is a Sample or Population, default should be True.
pub fn stdev(&self, is_sample: bool) -> Num

Calculates the standard deviation of the buffer.

Arguments
  • is_sample - If the data is a Sample or Population, default should be True.